(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     50470,       1132]*)
(*NotebookOutlinePosition[     51114,       1154]*)
(*  CellTagsIndexPosition[     51070,       1150]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "This ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program numerically computes discrete CMC surfaces or revolution in R^3, \
S^3 and H^3.  \nHere are some points on how to use it:\n      1) First one \
chooses the initial data for the surface, including the choice of spaceform \
and mean curvature, as given below.\n      2) There are two different kinds \
of examples here.  One kind is where the data has been found by hand and is \
all written \n          out in the initial data (Examples 1 to 12) -- for \
this kind one should not run \"Algorithm, STEP 3\".  The other kind is where \
only two adjacent points on the profile curve \n          are given (Example \
13 and onward), and then the \"profile curve finder\" (Algorithm, STEP 3) is \
employed.  \n      3) Depending on the case, different \"confirmations\" and \
\"plotters\" are used.  \n      4) It is explained in the comments before \
each initial data set which algorithm steps and which plotters should be \
used.\n      5) Because of problems with the way data is stored in variables, \
it is best to completely shut down and restart this program every successive \
time one wants to run it.  \n          In particular, \"Algorithm, STEP 3\" \
should never be run twice in a single session.\n      6) When running \
\"Algorithm, STEP 3\", sometimes the error \"",
  Cell[BoxData[
      FormBox["\<\"Infinite expression \\!\\(TraditionalForm\\`1/0\\) \
encountered\"\>", TraditionalForm]]],
  "\" will appear.  But this comes only from unallowable \n          data \
being inserted into the conditions of the \"While\" command.  Because these \
unallowable data are ignored by the \"While\" command, and we do in fact \n   \
       wish to ignore them, the program is still running correctly in spite \
of this error message.  \n      7) H\[Kappa] is the mean curvature of the \
surface with respect the chosen space form with constant sectional curvature \
\[Kappa].  On the other hand, H[m,n] is twice the \n          value of the \
mean curvature with respect to Euclidean 3-space, which is because the metric \
we have for the space forms is 4 (dx^2+dy^2+dz^2)/(1+\[Kappa] \
(x^2+y^2+z^2))^2.  \n          (So when \[Kappa]=0, the metric is 4 \
(dx^2+dy^2+dz^2), not the more typical dx^2+dy^2+dz^2.)  "
}], "Text"],

Cell["\<\
Example 1) Here we show that discrete cylinders in R^3 with nonconstant \
vertical spacing are CMC.
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\n", 
    \(H\[Kappa]temp = \[Alpha]/18; \), "\[IndentingNewLine]", 
    \(r[1] = \(r[
          2] = \(r[
            3] = \(r[
              4] = \(r[
                5] = \(r[
                  6] = \(r[
                    7] = \(r[
                      8] = \(r[9] = \(r[10] = 3\)\)\)\)\)\)\)\)\); \), "\n", 
    \(\[Alpha]final = 3\/2; \), "\[IndentingNewLine]", 
    \(h[1] = \(-3\); h[2] = \(-1\); h[3] = 0; \), "\n", 
    \(h[4] = 3; h[5] = 4; h[6] = 8; \), "\[IndentingNewLine]", 
    \(h[7] = 9; h[8] = 10; h[9] = 15; h[10] = 16; \), "\[IndentingNewLine]", 
    \(values = {{r[1], h[1]}, {r[2], h[2]}, {r[3], h[3]}, {r[4], 
          h[4]}, {r[5], h[5]}, {r[6], h[6]}, {r[7], h[7]}, {r[8], 
          h[8]}, {r[9], h[9]}, {r[10], h[10]}}; \), "\[IndentingNewLine]", 
    \(maxm = 9; \), "\[IndentingNewLine]", 
    \(ListPlot[values, PlotStyle \[Rule] PointSize[0.02]]\)}], "Input"],

Cell["\<\
Example 2) Unduloid in R^3 with constant vertical spacing:
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\[IndentingNewLine]", 
    \(H\[Kappa]temp = \(13 - 5\ \@13\)\/\(\(-117\) + 30\ \@13\) // 
        N; \), "\[IndentingNewLine]", 
    \(H\[Kappa]temp = 
      0.7171292729553327\ \[Alpha]; \), "\[IndentingNewLine]", 
    \(r[1] = \(r[2] = \(r[4] = \(r[5] = 1.0\)\)\); \), "\n", 
    \(r[3] = \(r[6] = \((\(-3\) + \@13)\) // N\); \), "\n", 
    \(\[Alpha]final = \(3\ r[3]\)\/\(3 + 2\ r[3] + r[3]\^2\) // N; \), "\n", 
    \(h[1] = \(-6.0\); \), "\n", 
    \(h[2] = \(-3.0\); \), "\n", 
    \(h[3] = 0.0; \), "\n", 
    \(h[4] = 3.0; \), "\n", 
    \(h[5] = 6.0; \), "\n", 
    \(h[6] = 9.0; \), "\n", 
    \(values = {{r[1], h[1]}, {r[2], h[2]}, {r[3], h[3]}, {r[4], 
          h[4]}, {r[5], h[5]}, {r[6], h[6]}}; \), "\[IndentingNewLine]", 
    \(maxm = 5; \), "\n", 
    \(tmpA = 
      ListPlot[values, 
        PlotStyle \[Rule] PointSize[0.02]]; \), "\[IndentingNewLine]", 
    \(tmpB = 
      ListPlot[values, PlotStyle \[Rule] PointSize[0.02], 
        PlotJoined -> True]; \), "\[IndentingNewLine]", 
    \(Show[tmpA, tmpB, AspectRatio -> True, 
      PlotRange -> {{\(-10\), 10}, {\(-10\), 10}}]; \)}], "Input"],

Cell["\<\
Example 3) Delaunay surface (unduloid) in R^3 with nonconstant vertical \
spacing:  
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\n", 
    \(H\[Kappa]temp = 
      0.36933385514009265\ \[Alpha]; \), "\[IndentingNewLine]", 
    \(\[Alpha]final\[InvisibleSpace] = 
      0.5471316123835278; \), "\[IndentingNewLine]", 
    \(a = 1.5597231895915273; \), "\n", 
    \(r[1] = \(r[2] = \(r[5] = \(r[6] = 1.0\)\)\); \), "\n", 
    \(r[3] = \(r[4] = \(r[7] = a\)\); \), "\n", 
    \(dh = \(1.0\ \@\(\(-2\)\ a\^3 - 9\ a\^2 - 8\ a - 1\)\)\/\@\(\(-4\)\ a - \
3\); \), "\n", 
    \(h[1] = \(-3\)\ dh; \), "\n", 
    \(h[2] = \(-dh\); \), "\n", 
    \(h[3] = 0; \), "\n", 
    \(h[4] = dh; \), "\n", 
    \(h[5] = 2\ dh; \), "\n", 
    \(h[6] = 4\ dh; \), "\n", 
    \(h[7] = 5\ dh; \), "\n", 
    \(maxm = 6; \), "\[IndentingNewLine]", 
    \(values = {{r[1], h[1]}, {r[2], h[2]}, {r[3], h[3]}, {r[4], 
          h[4]}, {r[5], h[5]}, {r[6], h[6]}, {r[7], h[7]}}; \), "\n", 
    \(ListPlot[values, PlotStyle \[Rule] PointSize[0.02]]\)}], "Input"],

Cell["\<\
Example 4) A simple Delaunay nodoid in R^3.  
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\n", 
    \(H\[Kappa]temp = \(-85\)\ \[Alpha]; \), "\[IndentingNewLine]", 
    \(a = 1.0/20; \), "\n", 
    \(dh = 1.0\/3\ \@\(\(-5\)\ a\^2 - 4\ a + 1\); \), "\n", 
    \(\[Alpha] = \(2\ a\^2\)\/\@\(4\ a\^4 + 12\ a\^3 + 5\ a\^2 - 6\ a + 1\); \
\), "\[IndentingNewLine]", 
    \(Clear[\[Alpha]]; \), "\[IndentingNewLine]", 
    \(\[Alpha]final = 0.005917159763313611; \), "\[IndentingNewLine]", 
    \(r[1] = 1.0; \), "\n", 
    \(r[2] = a; \), "\n", 
    \(r[3] = a; \), "\n", 
    \(r[4] = 1.0; \), "\n", 
    \(r[5] = a; \), "\n", 
    \(r[6] = a; \), "\n", 
    \(h[1] = \(-2\)\ dh; \), "\n", 
    \(h[2] = dh; \), "\n", 
    \(h[3] = \(-dh\); \), "\n", 
    \(h[4] = 2\ dh; \), "\n", 
    \(h[5] = 5\ dh; \), "\n", 
    \(h[6] = 3\ dh; \), "\n", 
    \(values = {{r[1], h[1]}, {r[2], h[2]}, {r[3], h[3]}, {r[4], 
          h[4]}, {r[5], h[5]}, {r[6], h[6]}}; \), "\n", 
    \(maxm = 5; \), "\[IndentingNewLine]", 
    \(tmpA = 
      ListPlot[values, 
        PlotStyle \[Rule] PointSize[0.02]]; \), "\[IndentingNewLine]", 
    \(tmpB = 
      ListPlot[values, PlotStyle \[Rule] PointSize[0.02], 
        PlotJoined -> True]; \), "\[IndentingNewLine]", 
    \(Show[tmpA, tmpB, AspectRatio -> True, 
      PlotRange -> {{\(-2\), 2}, {\(-2\), 2}}]; \), "\[IndentingNewLine]", 
    \(Null\)}], "Input"],

Cell["\<\
Example 5) A nonconformal unduloid in R^3 with constant vertical spacing:  
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\n", 
    \(H\[Kappa]temp = 0.7600353344758148\ \[Alpha]; \), "\n", 
    \(\[Alpha]final = 0.39471849056452807; \), "\[IndentingNewLine]", 
    \(h[1] = \(-2\); h[2] = \(-1\); h[3] = 0; h[4] = 1; h[5] = 2; h[6] = 3; 
    h[7] = 4; h[8] = 5; h[9] = 6; h[10] = 7; \), "\n", 
    \(r[1] = 1; \), "\n", 
    \(r[2] = 1; \), "\n", 
    \(r[3] = 0.8319292834021221; \), "\n", 
    \(r[4] = 0.6602651208306597; \), "\n", 
    \(r[5] = 0.6864012614863299; \), "\n", 
    \(r[6] = 0.8785575700510736; \), "\n", 
    \(r[7] = 1.0170778610483509; \), "\n", 
    \(r[8] = 0.9737356499446731; \), "\n", 
    \(r[9] = 0.7847547417969657; \), "\n", 
    \(r[10] = 0.6453171909236644; \), "\n", 
    \(maxm = 9; \), "\n", 
    \(values = {{r[1], h[1]}, {r[1], h[1]}, {r[2], h[2]}, {r[3], 
          h[3]}, {r[4], h[4]}, {r[5], h[5]}, {r[6], h[6]}, {r[7], 
          h[7]}, {r[8], h[8]}, {r[9], h[9]}, {r[10], h[10]}}; \), "\n", 
    \(tmpA = ListPlot[values, PlotStyle \[Rule] PointSize[0.02]]; \), "\n", 
    \(tmpB = 
      ListPlot[values, PlotStyle \[Rule] PointSize[0.02], 
        PlotJoined -> True]; \), "\n", 
    \(Show[tmpA, tmpB]; \)}], "Input"],

Cell["\<\
Example 6) A surface in R^3 with constant hyperbolic speed (\"quasi-conformal\
\") parametrization, i.e. the cross ratios of the quadrilaterals are \
constant.  This is a kind of conformality condition.  (True conformality is \
that the cross ratio is always exactly -1.)
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\n", 
    \(H\[Kappa]temp = 0.7556900947358763\ \[Alpha]; \), "\n", 
    \(\[Alpha]final = 0.39698813321729953; \), "\[IndentingNewLine]", 
    \(h[1] = 1; h[2] = 2; \), "\n", 
    \(r[1] = 1; r[2] = 0.98; \), "\n", 
    \(r[3] = 0.8278314829645018; 
    h[3] = 2.897222022679383; \), "\[IndentingNewLine]", 
    \(r[4] = 0.6896713584501286; 
    h[4] = 3.6480403384859295; \), "\[IndentingNewLine]", 
    \(r[5] = 0.6551620524548313; 
    h[5] = 4.326318596182285; \), "\[IndentingNewLine]", 
    \(r[6] = 0.7400441029543396; 
    h[6] = 5.024700026433265; \), "\[IndentingNewLine]", 
    \(r[7] = 0.900805007427301; 
    h[7] = 5.833815757410824; \), "\[IndentingNewLine]", 
    \(r[8] = 1.0114478471722468; 
    h[8] = 6.791856237985496; \), "\[IndentingNewLine]", 
    \(r[9] = 0.9539048443884937; 
    h[9] = 7.78261247256889; \), "\[IndentingNewLine]", 
    \(r[10] = 0.7926191411924897; 
    h[10] = 8.646214832490255; \), "\[IndentingNewLine]", 
    \(maxm = 9; \), "\n", 
    \(values = {{r[1], h[1]}, {r[1], h[1]}, {r[2], h[2]}, {r[3], 
          h[3]}, {r[4], h[4]}, {r[5], h[5]}, {r[6], h[6]}, {r[7], 
          h[7]}, {r[8], h[8]}, {r[9], h[9]}, {r[10], h[10]}}; \), "\n", 
    \(tmpA = ListPlot[values, PlotStyle \[Rule] PointSize[0.02]]; \), "\n", 
    \(tmpB = 
      ListPlot[values, PlotStyle \[Rule] PointSize[0.02], 
        PlotJoined -> True]; \), "\n", 
    \(Show[tmpA, tmpB]; \)}], "Input"],

Cell["\<\
Example 7) A surface in S^3 with constant hyperbolic speed (\"quasi-conformal\
\") parametrization:  
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1,  then run Plotter 1, but not Plotter 2.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 1; \), "\n", 
    \(H\[Kappa]temp = 1.8511673740392585\ \[Alpha]; \), "\n", 
    \(\[Alpha]final = 0.16205990025926073; \), "\[IndentingNewLine]", 
    \(h[1] = \(-0.5\); h[2] = 0; \), "\n", 
    \(r[1] = 0.3; r[2] = 0.4; \), "\n", 
    \(r[3] = 0.676607279854556448186258283922905489532383995638; 
    h[3] = 0.714059793438485221012315999753268362514013089422; \), "\n", 
    \(r[4] = 1.673564231208823394018947420526; 
    h[4] = 1.922154413815239832714628596881; \), "\n", 
    \(r[5] = 3.799688952583472569830350594887; 
    h[5] = \(-1.12045597270257928767116100748510893734241944304\); \), "\n", 
    \(r[6] = 0.974663787195755603465398010080452404278192424048; 
    h[6] = \(-0.912350706655932850315225642529457494162745069113\); \), "\
\[IndentingNewLine]", 
    \(maxm = 5; \), "\n", 
    \(values = {{r[1], h[1]}, {r[1], h[1]}, {r[2], h[2]}, {r[3], 
          h[3]}, {r[4], h[4]}, {r[5], h[5]}, {r[6], h[6]}}; \), "\n", 
    \(tmpA = ListPlot[values, PlotStyle \[Rule] PointSize[0.02]]; \), "\n", 
    \(tmpB = 
      ListPlot[values, PlotStyle \[Rule] PointSize[0.02], 
        PlotJoined -> True]; \), "\n", 
    \(Show[tmpA, tmpB]; \)}], "Input"],

Cell["\<\
Example 8) A nonconformal minimal surface in S^3:  
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1,  then run Plotter 1, but not Plotter 2.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 1; \), "\n", 
    \(H\[Kappa]temp = 0; \), "\n", 
    \(\[Alpha]final = 0.11560343109274111; \), "\[IndentingNewLine]", 
    \(h[1] = \(-0.4\); h[2] = \(-0.35\); h[3] = \(-0.3\); h[4] = \(-0.25\); 
    h[5] = \(-0.2\); h[6] = \(-0.15\); h[7] = \(-0.1\); h[8] = \(-0.05\); 
    h[9] = 0; h[10] = 0.05; \), "\n", 
    \(r[1] = 0.35; r[2] = 0.4; r[3] = 0.450837769534866; \), "\n", 
    \(r[4] = 0.5011552699167381; r[5] = 0.5500984707962404; 
    r[6] = 0.5971849989144771; \), "\n", 
    \(r[7] = 0.642177979256725; r[8] = 0.684992149840414; 
    r[9] = 0.7256314751893436; r[10] = 0.7641500431455006; \), "\n", 
    \(maxm = 9; \), "\n", 
    \(values = {{r[1], h[1]}, {r[1], h[1]}, {r[2], h[2]}, {r[3], 
          h[3]}, {r[4], h[4]}, {r[5], h[5]}, {r[6], h[6]}, {r[7], 
          h[7]}, {r[8], h[8]}, {r[9], h[9]}, {r[10], h[10]}}; \), "\n", 
    \(tmpA = ListPlot[values, PlotStyle \[Rule] PointSize[0.02]]; \), "\n", 
    \(tmpB = 
      ListPlot[values, PlotStyle \[Rule] PointSize[0.02], 
        PlotJoined -> True]; \), "\n", 
    \(Show[tmpA, tmpB]; \)}], "Input"],

Cell["\<\
Example 9) Here we see that discrete cylinders in S^3 with nonconstant \
vertical spacing are CMC:  
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1,  then run Plotter 1, but not Plotter 2.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 1; \), "\[IndentingNewLine]", 
    \(H\[Kappa]temp = 4.0\ \[Alpha]; \), "\[IndentingNewLine]", 
    \(\[Alpha]final = 0.14433756729740646; \), "\[IndentingNewLine]", 
    \(dh = 0.05; \), "\n", 
    \(rr = 2.0; \), "\n", 
    \(\[Alpha] = 1\/\@\(16\ \((rr\^2 - 1)\)\); \), "\n", 
    \(Clear[\[Alpha]]; \), "\[IndentingNewLine]", 
    \(h[1] = \(-3\)\ dh; \), "\n", 
    \(h[2] = \(-dh\); \), "\n", 
    \(h[3] = 0.0; \), "\n", 
    \(h[4] = 3\ dh; \), "\n", 
    \(h[5] = 4\ dh; \), "\n", 
    \(h[6] = 8\ dh; \), "\n", 
    \(r[1] = rr - \@\(\(-1\) + rr\^2 - h[1]\^2\); \), "\n", 
    \(r[2] = rr - \@\(\(-1\) + rr\^2 - h[2]\^2\); \), "\n", 
    \(r[3] = rr - \@\(\(-1\) + rr\^2 - h[3]\^2\); \), "\n", 
    \(r[4] = rr - \@\(\(-1\) + rr\^2 - h[4]\^2\); \), "\n", 
    \(r[5] = rr - \@\(\(-1\) + rr\^2 - h[5]\^2\); \), "\n", 
    \(r[6] = rr - \@\(\(-1\) + rr\^2 - h[6]\^2\); \), "\n", 
    \(values = {{r[1], h[1]}, {r[2], h[2]}, {r[3], h[3]}, {r[4], 
          h[4]}, {r[5], h[5]}, {r[6], h[6]}}; \), "\n", 
    \(maxm = 5; \), "\[IndentingNewLine]", 
    \(ListPlot[values, PlotStyle \[Rule] PointSize[0.02]]\)}], "Input"],

Cell["\<\
Example 10) Here we see that discrete cylinders in H^3 with nonconstant \
vertical spacing are CMC:  
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1, then run Plotter 1.\
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = 12.0\ \[Alpha]; \), "\[IndentingNewLine]", 
    \(dh = 0.1; \), "\n", 
    \(rr = 2; \), "\n", 
    \(\[Alpha]final = 
      1\/\@\(16\ \((rr\^2 + 1)\)\) // N; \), "\[IndentingNewLine]", 
    \(h[1] = \(-3\)\ dh; h[2] = \(-dh\); h[3] = 0.0; h[4] = 3\ dh; 
    h[5] = 4\ dh; h[6] = 8\ dh; \), "\n", 
    \(r[1] = \@\(1 + rr\^2 - h[1]\^2\) - rr; 
    r[2] = \@\(1 + rr\^2 - h[2]\^2\) - rr; 
    r[3] = \@\(1 + rr\^2 - h[3]\^2\) - rr; \), "\n", 
    \(r[4] = \@\(1 + rr\^2 - h[4]\^2\) - rr; 
    r[5] = \@\(1 + rr\^2 - h[5]\^2\) - rr; 
    r[6] = \@\(1 + rr\^2 - h[6]\^2\) - rr; \), "\n", 
    \(maxm = 5; \), "\[IndentingNewLine]", 
    \(values = {{r[1], h[1]}, {r[2], h[2]}, {r[3], h[3]}, {r[4], 
          h[4]}, {r[5], h[5]}, {r[6], h[6]}}; \), "\n", 
    \(ListPlot[values, PlotStyle \[Rule] PointSize[0.02]]\)}], "Input"],

Cell["\<\
Example 11) A nonconformal Delaunay surface in H^3, with 0<|H|<1:  
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1, then run Plotter 1.\
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = 1.3031075978515285\ \[Alpha]; \), "\n", 
    \(\[Alpha]final = 0.23021890171970316; \), "\[IndentingNewLine]", 
    \(h[1] = \(-0.4\); h[2] = \(-0.35\); h[3] = \(-0.3\); h[4] = \(-0.25\); 
    h[5] = \(-0.2\); h[6] = \(-0.15\); h[7] = \(-0.1\); h[8] = \(-0.05\); 
    h[9] = 0; h[10] = 0.05; \), "\n", 
    \(r[1] = 0.2; r[2] = 0.2; \), "\[IndentingNewLine]", 
    \(r[3] = 0.21164740802233467; 
    r[4] = 0.2363928805808025; \), "\[IndentingNewLine]", 
    \(r[5] = 0.27644652948778875; 
    r[6] = 0.3349874804564269; \), "\[IndentingNewLine]", 
    \(r[7] = 0.41568908856969844; 
    r[8] = 0.5202208797952523; \), "\[IndentingNewLine]", 
    \(r[9] = 0.6432723840612092; 
    r[10] = 0.7716179609185361; \), "\[IndentingNewLine]", 
    \(maxm = 9; \), "\[IndentingNewLine]", 
    \(values = {{r[1], h[1]}, {r[1], h[1]}, {r[2], h[2]}, {r[3], 
          h[3]}, {r[4], h[4]}, {r[5], h[5]}, {r[6], h[6]}, {r[7], 
          h[7]}, {r[8], h[8]}, {r[9], h[9]}, {r[10], 
          h[10]}}; \), "\[IndentingNewLine]", 
    \(ListPlot[values, PlotStyle \[Rule] PointSize[0.02]]; \)}], "Input"],

Cell["\<\
Example 12) Another nonconformal Delaunay surface in H^3, with |H|>1: 
          Run Algorithm, STEP 1 and STEP 2, but not STEP 3, then run \
Confirmation STEP 1, then run Plotter 1.\
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = \(-4.550303810904895\)\ \[Alpha]; \), "\n", 
    \(\[Alpha]final = 0.4395310913541575; \), "\[IndentingNewLine]", 
    \(h[1] = \(-0.4\); h[2] = \(-0.35\); h[3] = \(-0.3\); h[4] = \(-0.25\); 
    h[5] = \(-0.2\); h[6] = \(-0.25\); h[7] = \(-0.3\); h[8] = \(-0.25\); 
    h[9] = \(-0.2\); h[10] = \(-0.15\); \), "\n", 
    \(r[1] = 0.3; r[2] = 0.2; \), "\n", 
    \(r[3] = 0.41632832255236624; r[4] = 0.4103884056542382; \), "\n", 
    \(r[5] = 0.38551144570905044; r[6] = 0.19918519913636973; \), "\n", 
    \(r[7] = 0.41879722780040757; r[8] = 0.4275403844455409; \), "\n", 
    \(r[9] = 0.42089106382521874; r[10] = 0.2253042651521808; \), "\n", 
    \(maxm = 9; \), "\n", 
    \(values = {{r[1], h[1]}, {r[1], h[1]}, {r[2], h[2]}, {r[3], 
          h[3]}, {r[4], h[4]}, {r[5], h[5]}, {r[6], h[6]}, {r[7], 
          h[7]}, {r[8], h[8]}, {r[9], h[9]}, {r[10], h[10]}}; \), "\n", 
    \(tmpA = ListPlot[values, PlotStyle \[Rule] PointSize[0.02]]; \), "\n", 
    \(tmpB = 
      ListPlot[values, PlotStyle \[Rule] PointSize[0.02], 
        PlotJoined -> True]; \), "\n", 
    \(Show[tmpA, tmpB]; \)}], "Input"],

Cell["\<\
Example 13) This is a discrete cylinder in R^3 with constant vertical \
spacing.  
          Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\n", 
    \(H\[Kappa]temp = 0.25; \), "\n", 
    \(rtemp[1] = 1.0; \), "\n", 
    \(rtemp[2] = 1.0; \), "\n", 
    \(htemp[1] = 0.0; \), "\n", 
    \(htemp[2] = 1.0; \), "\n", 
    \(maxmtemp = 15; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 14) Now for a noncylindrical Delaunay unduloid in R^3 with \
nonconstant vertical spacing:  
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\n", 
    \(H\[Kappa]temp = 0.2845858468364701; \), "\n", 
    \(htemp[1] = 3.0; \), "\[IndentingNewLine]", 
    \(htemp[2] = 6.0; \), "\[IndentingNewLine]", 
    \(rtemp[1] = 1; \), "\n", 
    \(rtemp[2] = 1; \), "\n", 
    \(maxmtemp = 30; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 15) A nodoid in R^3:  
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\n", 
    \(H\[Kappa]temp = \(-0.3\); \), "\n", 
    \(htemp[1] = \(-2\); \), "\[IndentingNewLine]", 
    \(htemp[2] = \(-1\); \), "\n", 
    \(rtemp[1] = 1; \), "\n", 
    \(rtemp[2] = 1; \), "\[IndentingNewLine]", 
    \(maxmtemp = 20; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 16) An unduloid in R^3.  
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\n", 
    \(H\[Kappa]temp = 1.0; \), "\n", 
    \(htemp[1] = \(-0.025\); \), "\[IndentingNewLine]", 
    \(htemp[2] = 0.025; \), "\[IndentingNewLine]", 
    \(rtemp[1] = 0.3; \), "\n", 
    \(rtemp[2] = 0.3; \), "\n", 
    \(maxmtemp = 100; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 17) A nodoid in R^3.  
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\n", 
    \(H\[Kappa]temp = \(-1.0\); \), "\n", 
    \(htemp[1] = \(-0.025\); \), "\[IndentingNewLine]", 
    \(htemp[2] = 0.025; \), "\[IndentingNewLine]", 
    \(rtemp[1] = 0.3; \), "\n", 
    \(rtemp[2] = 0.3; \), "\n", 
    \(maxmtemp = 100; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 18) A constant hyperbolic speed (\"quasi-conformal\") \
parametrization, a catenoid in R^3 (it turns out that all dh_{m+1,m} is \
constant, i.e. independent of m).  
Note that here we will be adding the condition that the cross ratios of the \
quadrilaterals are a constant.  This is a kind of conformality condition.  \
(True conformality is that the cross ratio is always exactly -1.)
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 0; \), "\n", 
    \(H\[Kappa]temp = 0.0; \), "\n", 
    \(htemp[1] = \(-0.025\); \), "\[IndentingNewLine]", 
    \(htemp[2] = 0.025; \), "\[IndentingNewLine]", 
    \(rtemp[1] = 1.0; \), "\n", 
    \(rtemp[2] = 1.0; \), "\n", 
    \(maxmtemp = 102; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 19) A constant hyperbolic speed (\"quasi-conformal\") parametrization \
of a Delaunay surface in S^3 that closes on itself to become an embedded \
torus.  
Note that here we will be adding the condition that the cross ratios of the \
quadrilaterals are a constant.  This is a kind of conformality condition.  \
(True conformality is that the cross ratio is always exactly -1.)
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1 and Plotter 2.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = 1; \), "\n", 
    \(H\[Kappa]temp = 1.3485; \), "\n", 
    \(htemp[1] = \(-0.049947\); \), "\[IndentingNewLine]", 
    \(htemp[2] = 0.049947; \), "\[IndentingNewLine]", 
    \(rtemp[1] = 0.3; \), "\n", 
    \(rtemp[2] = 0.3; \), "\n", 
    \(maxmtemp = 102; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 20) A minimal example in H^3:  
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1 and Plotter 3 and Plotter 4.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = 0.0; \), "\n", 
    \(rtemp[1] = 0.9913991417; \), "\n", 
    \(rtemp[2] = 1; \), "\n", 
    \(htemp[1] = \(-0.005\); \), "\n", 
    \(htemp[2] = 0.0; \), "\n", 
    \(maxmtemp = 40; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 21) A minimal example in H^3:  
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1 and Plotter 3 and Plotter 4.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = 0.0; \), "\n", 
    \(rtemp[1] = 1.281765730881669683938008123909; \), "\n", 
    \(rtemp[2] = 1.469728846958890357130788321033; \), "\n", 
    \(htemp[1] = 0.782997389364556374502637426831; \), "\n", 
    \(htemp[2] = 1.061963485893203535160632851315; \), "\n", 
    \(maxmtemp = 90; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 22) A minimal example in H^3:  
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1 and Plotter 3 and Plotter 4.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = 0.0; \), "\n", 
    \(rtemp[1] = 1.056565730881669683938008123909; \), "\n", 
    \(rtemp[2] = 1.069728846958890357130788321033; \), "\n", 
    \(htemp[1] = 0.782997389364556374502637426831; \), "\n", 
    \(htemp[2] = 1.061963485893203535160632851315; \), "\n", 
    \(maxmtemp = 26; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 23) A minimal example in H^3:  
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1 and Plotter 3 and Plotter 4.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = 0.0; \), "\n", 
    \(rtemp[1] = 1.090565730881669683938008123909; \), "\n", 
    \(rtemp[2] = 1.069728846958890357130788321033; \), "\n", 
    \(htemp[1] = 0.782997389364556374502637426831; \), "\n", 
    \(htemp[2] = 1.061963485893203535160632851315; \), "\n", 
    \(maxmtemp = 35; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 24) Next we give an example in H^3 with the constant value of the \
mean curvature lieing strictly between 0 and 1:  
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1 and Plotter 3 and Plotter 4.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = 0.3; \), "\n", 
    \(htemp[1] = \(-0.4\); \), "\[IndentingNewLine]", 
    \(htemp[2] = \(-0.35\); \), "\[IndentingNewLine]", 
    \(rtemp[1] = 0.2; \), "\n", 
    \(rtemp[2] = 0.2; \), "\[IndentingNewLine]", 
    \(maxmtemp = 21; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 25) An H^3 example with the constant value of the mean curvature \
strictly greater than 1:  
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1 and Plotter 3 and Plotter 4.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = 2; \), "\n", 
    \(htemp[1] = \(-0.4\); \), "\[IndentingNewLine]", 
    \(htemp[2] = \(-0.35\); \), "\n", 
    \(rtemp[1] = 0.3; \), "\n", 
    \(rtemp[2] = 0.2; \), "\[IndentingNewLine]", 
    \(maxmtemp = 10; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 26) A constant hyperbolic speed (\"quasi-conformal\") \
parametrization, an unduloid in H^3, with the constant value of the mean \
curvature strictly greater than 1:  
Note that here we will be adding the condition that the cross ratios of the \
quadrilaterals are a constant.  This is a kind of conformality condition.  \
(True conformality is that the cross ratio is always exactly -1.)
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1 and Plotter 3 and Plotter 4.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = 1.3; \), "\n", 
    \(htemp[1] = \(-0.025\); \), "\[IndentingNewLine]", 
    \(htemp[2] = 0.025; \), "\[IndentingNewLine]", 
    \(rtemp[1] = 0.3; \), "\n", 
    \(rtemp[2] = 0.3; \), "\n", 
    \(maxmtemp = 50; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 27) A constant hyperbolic speed (\"quasi-conformal\") \
parametrization, an embedded catenoid cousin in H^3 (with mean curvature \
exactly 1).  
Note that here we will be adding the condition that the cross ratios of the \
quadrilaterals are a constant.  This is a kind of conformality condition.  \
(True conformality is that the cross ratio is always exactly -1.)
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1 and Plotter 3 and Plotter 4.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = 1.0; \), "\n", 
    \(htemp[1] = \(-0.025\); \), "\[IndentingNewLine]", 
    \(htemp[2] = 0.025; \), "\[IndentingNewLine]", 
    \(rtemp[1] = 0.3; \), "\n", 
    \(rtemp[2] = 0.3; \), "\n", 
    \(maxmtemp = 50; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
Example 28) A constant hyperbolic speed (\"quasi-conformal\") \
parametrization, an embedded minimal rotational Willmore channel surface in \
H^3 (see page 141 of the text by 
Udo Hertrich-Jeromin).  Note that here we will be adding the condition that \
the cross ratios of the quadrilaterals are a constant.  This is a kind of \
conformality condition.  
(True conformality is that the cross ratio is always exactly -1.)
         Run Algorithm, all three steps: STEP 1 and STEP 2 and STEP 3, then \
run Confirmation STEP 2, then run Plotter 1 and Plotter 3 and Plotter 4.  \
\>", "Text"],

Cell[BoxData[{
    \(\[Kappa]temp = \(-1\); \), "\n", 
    \(H\[Kappa]temp = 0.0; \), "\n", 
    \(htemp[1] = \(-0.025\); \), "\[IndentingNewLine]", 
    \(htemp[2] = 0.025; \), "\[IndentingNewLine]", 
    \(rtemp[1] = 0.3; \), "\n", 
    \(rtemp[2] = 0.3; \), "\n", 
    \(maxmtemp = 100; \), "\[IndentingNewLine]", 
    \(choiceof\[Alpha] = 2; \)}], "Input"],

Cell["\<\
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
----------------------------------------
------------------------------------------------------------------------------\
------------------------------------------------------------------------------\
----------------------------------------

Algorithm, STEP 1) Here we define the matrix for the linear system in the \
upcoming algorithm:  \
\>", "Text"],

Cell[BoxData[
    \(bigmatrix[
        m_] := {{r[m]\^2, 0, 0, 0, r[m], 0, 
          0, \[Alpha]\ \((1 + \[Kappa]\ \((h[m]\^2 + r[m]\^2)\))\)}, {0, 
          r[m + 1]\^2, 0, 0, 0, r[m + 1], 
          0, \[Alpha]\ \((1 + \[Kappa]\ \((h[m + 1]\^2 + 
                      r[m + 1]\^2)\))\)}, {0, 0, h[m + 1] - h[m], 
          h[m + 1] - h[m], r[m + 1] - r[m], r[m + 1] - r[m], 0, 0}, {0, 
          0, \(-\((r[m + 1] - r[m])\)\), r[m + 1] - r[m], 
          h[m + 1] - h[m], \(-\((h[m + 1] - h[m])\)\), 0, 0}, {\(-1\), 1, 0, 
          0, 0, 0, 
          0, \(\[Alpha]\ \((\[Kappa]\ \((h[m + 1]\^2 - h[m]\^2 + r[m + 1]\^2 \
- r[m]\^2)\))\)\)\/\(r[m]\ r[m + 1]\)}, {1\/2\ \((\((h[m + 1] - h[m])\)\^2 + \
\((r[m + 1] - r[m])\)\^2)\), 
          1\/2\ \((\((h[m + 1] - h[m])\)\^2 + \((r[m + 1] - r[m])\)\^2)\), \
\(-\((h[m + 1] - h[m])\)\), h[m + 1] - h[m], \(-\((r[m + 1] - r[m])\)\), 
          r[m + 1] - r[m], 
          0, \(-\(\(\[Alpha]\ \((\((1 + 
                          1\/2\ \[Kappa]\ \((h[m + 1]\^2 + h[m]\^2 + 
                                r[m + 1]\^2 + 
                                r[m]\^2)\))\)\ \((\((h[m + 1] - h[m])\)\^2 + \
\((r[m + 1] - r[m])\)\^2)\))\)\)\/\(r[m]\ r[
                    m + 1]\)\)\)}, {1 + \[Kappa]\ \((h[m]\^2 + r[m]\^2)\), 0, 
          2\ \[Kappa]\ h[m], 0, 2\ \[Kappa]\ r[m], 0, \(-2\), 0}, {0, 
          1 + \[Kappa]\ \((h[m + 1]\^2 + r[m + 1]\^2)\), 0, 
          2\ \[Kappa]\ h[m + 1], 0, 2\ \[Kappa]\ r[m + 1], \(-2\), 
          0}}; \)], "Input"],

Cell["\<\
Algorithm, STEP 2) Here we define some other needed terms (a single 0 should \
appear in the output): \
\>", "Text"],

Cell[BoxData[{
    \(xxx[m_] := 
      Simplify[Solve[
          bigmatrix[
                m] . {{H[m, n]}, {H[m + 1, n]}, {nn\[Eta][m, n]}, {nn\[Eta][
                    m + 1, n]}, {nn\[Rho][m, n]}, {nn\[Rho][m + 1, 
                    n]}, {H\[Kappa]}, {1}} \[Equal] {{0}, {0}, {0}, {0}, {0}, \
{0}, {0}, {0}}, {H[m, n], H[m + 1, n], nn\[Eta][m, n], nn\[Eta][m + 1, n], 
            nn\[Rho][m, n], nn\[Rho][m + 1, n]}]]; \), "\n", 
    \(\(Simplify[\((nn\[Eta][m, n] /. \[InvisibleSpace]xxx[m])\)\^2 + \((nn\
\[Rho][m, n] /. \[InvisibleSpace]xxx[m])\)\^2 - \((nn\[Eta][m + 1, n] \
/. \[InvisibleSpace]xxx[m])\)\^2 - \((nn\[Rho][m + 1, n] \
/. \[InvisibleSpace]xxx[m])\)\^2]\)\[LeftDoubleBracket]1\[RightDoubleBracket] \
// Chop\), "\n", 
    \(nn\[Eta]plus[m_, 
        n_] = \((nn\[Eta][m, n] /. \[InvisibleSpace]xxx[
              m])\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \), "\n", 
    \(nn\[Eta]minus[m_, 
        n_] = \((nn\[Eta][m, n] /. \[InvisibleSpace]xxx[
              m - 1])\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \), "\n", 
    \(nn\[Rho]plus[m_, 
        n_] = \((nn\[Rho][m, n] /. \[InvisibleSpace]xxx[
              m])\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \), "\n", 
    \(nn\[Rho]minus[m_, 
        n_] = \((nn\[Rho][m, n] /. \[InvisibleSpace]xxx[
              m - 1])\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \), "\n", 
    \(Hplus[m_, 
        n_] = \((H[m, n] /. \[InvisibleSpace]xxx[
              m])\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \), "\n", 
    \(Hminus[m_, 
        n_] = \((H[m, n] /. \[InvisibleSpace]xxx[
              m - 1])\)\[LeftDoubleBracket]1\[RightDoubleBracket]; \), "\n", 
    \(InputForm[
      nn\[Eta]diff[m_, n_] = 
        Simplify[nn\[Eta]plus[m, n] - nn\[Eta]minus[m, n]]]; \), "\n", 
    \(InputForm[
      nn\[Rho]diff[m_, n_] = 
        Simplify[nn\[Rho]plus[m, n] - nn\[Rho]minus[m, n]]]; \), "\n", 
    \(InputForm[
      Hdiff[m_, n_] = Simplify[Hplus[m, n] - Hminus[m, n]]]; \), "\n", 
    \(\[Kappa] = \[Kappa]temp; \), "\n", 
    \(H\[Kappa] = H\[Kappa]temp; \)}], "Input"],

Cell["\<\
Algorithm, STEP 3) Here is the algorithm that determines the profile curve \
numerically (the term \"crossratio\" is not the actual cross ratio, it \
differs from the true cross ratio by a constant factor):  \
\>", "Text"],

Cell[BoxData[{
    \(r[1] = rtemp[1]; \), "\n", 
    \(r[2] = rtemp[2]; \), "\n", 
    \(h[1] = htemp[1]; \), "\n", 
    \(h[2] = htemp[2]; \), "\n", 
    \(maxm = maxmtemp; \), "\n", 
    \(Chop[
      Simplify[nn\[Eta]minus[2, n]\^2 + nn\[Rho]minus[2, n]\^2 - 
          1]]\), "\n", 
    \(tmp = 
      NSolve[Chop[
          Simplify[
            nn\[Eta]plus[1, n]\^2 + nn\[Rho]plus[1, n]\^2 - 
              1]], \[Alpha]]\), "\n", 
    \(\[Alpha] = \((\[Alpha] /. \[InvisibleSpace]tmp)\)\[LeftDoubleBracket]
        choiceof\[Alpha]\[RightDoubleBracket]; 
    Print["\<\[Alpha] is \>", \[Alpha]]; \), "\n", 
    \(crossratio = 
      Chop[Simplify[\(\((h[2] - h[1])\)\^2 + \((r[2] - r[1])\)\^2\)\/\(r[1]\ \
r[2]\)]]; Print["\<crossratio is \>", crossratio]; \), "\n", 
    \(Chop[
      Simplify[nn\[Eta]minus[2, n]\^2 + nn\[Rho]minus[2, n]\^2 - 
          1]]\), "\n", 
    \(Chop[
      Simplify[nn\[Eta]plus[1, n]\^2 + nn\[Rho]plus[1, n]\^2 - 1]]\), "\n", 
    \(Do[{tmp = 
          NSolve[{Chop[Simplify[nn\[Eta]diff[m, n]]] \[Equal] 0, 
              Chop[Simplify[\((h[m + 1] - h[m])\)\^2 + \((r[m + 1] - \
r[m])\)\^2 - crossratio\ r[m]\ r[m + 1]]] \[Equal] 0}, {r[m + 1], 
              h[m + 1]}]\ ;  (*Print["\<m is \>", m, "\<,  tmp is \>", tmp]; *) 
          j = 1; rrr[
            m + 1] = \((r[
                  m + 1] /. \[InvisibleSpace]tmp)\)\[LeftDoubleBracket]
            j\[RightDoubleBracket]; 
        hhh[m + 1] = \((h[
                  m + 1] /. \[InvisibleSpace]tmp)\)\[LeftDoubleBracket]
            j\[RightDoubleBracket]; 
        While[Abs[Im[rrr[m + 1]]] > 0.0001 || 
            Abs[\((rrr[m + 1] - r[m - 1])\)^2 + \((hhh[m + 1] - 
                        h[m - 1])\)^2] < 0.0000001 || 
            Re[rrr[m + 1]] < 0.0001, {j = j + 1; 
            rrr[m + 1] = \((r[
                      m + 1] /. \[InvisibleSpace]tmp)\)\[LeftDoubleBracket]
                j\[RightDoubleBracket]; 
            hhh[m + 1] = \((h[
                      m + 1] /. \[InvisibleSpace]tmp)\)\[LeftDoubleBracket]
                j\[RightDoubleBracket]; }]; 
        r[m + 1] = \((r[m + 1] /. \[InvisibleSpace]tmp)\)\[LeftDoubleBracket]
            j\[RightDoubleBracket]; 
        h[m + 1] = \((h[m + 1] /. \[InvisibleSpace]tmp)\)\[LeftDoubleBracket]
            j\[RightDoubleBracket]; }, {m, 2, maxm}]; \), "\n", 
    \(values = Table[{r[jj], h[jj]}, {jj, 1, maxm + 1}]; \), "\n", 
    \(MoebiusTransformedValues = 
      Table[{\(2\ r[jj]\)\/\(\((h[jj] + 1)\)\^2 + r[jj]\^2\), \(r[jj]\^2 + \
h[jj]\^2 - 1\)\/\(\((h[jj] + 1)\)\^2 + r[jj]\^2\)}, {jj, 1, 
          maxm + 1}]; \), "\n", 
    \(MoebiusTransformedValuesS3 = 
      Table[{\(r[jj]\^2 + h[jj]\^2 - 1\)\/\(\((r[jj] + 1)\)\^2 + h[jj]\^2\), \
\(2\ h[jj]\)\/\(\((r[jj] + 1)\)\^2 + h[jj]\^2\)}, {jj, 1, 
          maxm + 1}]; \), "\n", 
    \(tmpA = ListPlot[values, PlotStyle \[Rule] PointSize[0.005]]; \), "\n", 
    \(tmpB = 
      ListPlot[values, PlotStyle \[Rule] PointSize[0.005], 
        PlotJoined \[Rule] True]; \), "\n", 
    \(Show[tmpA, tmpB, PlotRange \[Rule] All]; \)}], "Input"],

Cell["\<\
Confirmation STEP 1) We confirm that the above numerics is correct here.  \
Everything should be zero, except the last numbers, which are the mean \
curvature w.r.t. 
Euclidean space (printed twice) and then w.r.t. the chosen space form:  \
\>", "Text"],

Cell[BoxData[
    \(Do[Print[Chop[nn\[Eta]diff[m, n], 0.00001] // Simplify, "\<   \>", 
        Chop[nn\[Rho]diff[m, n], 0.00001] // Simplify, "\<   \>", 
        Chop[Hdiff[m, n], 0.00001] // Simplify, "\<   \>", 
        Transpose[
          Chop[bigmatrix[
                  m] . {{Hplus[m, n]}, {Hplus[m + 1, n]}, {nn\[Eta]plus[m, 
                      n]}, {nn\[Eta]plus[m + 1, n]}, {nn\[Rho]plus[m, 
                      n]}, {nn\[Rho]plus[m + 1, n]}, {H\[Kappa]}, {1}} // 
              Simplify, 0.00001]], "\<   \>", 
        Chop[Hplus[m, n]/2 /. {\[Alpha] -> \[Alpha]final}, 0.00001] // 
          Simplify, "\<   \>", 
        Chop[\(Hplus[m, n]/
                  Sqrt[nn\[Eta]plus[m, n]^2 + nn\[Rho]plus[m, n]^2]\)/
                2 /. {\[Alpha] -> \[Alpha]final}, 0.00001] // 
          Simplify, "\<   \>", 
        Chop[H\[Kappa] /. {\[Alpha] -> \[Alpha]final}, 0.00001] // 
          Simplify], {m, 2, maxm - 1}]; \)], "Input"],

Cell["\<\
Confirmation STEP 2) We confirm that the above numerics is correct here.  \
Everything should be zero, except the last numbers, which are the mean \
curvature w.r.t. 
Euclidean space (printed twice) and then w.r.t. the chosen space form:  \
\>", "Text"],

Cell[BoxData[
    \(Do[Print[Chop[nn\[Eta]diff[m, n], 0.00001] // Simplify, "\<   \>", 
        Chop[nn\[Rho]diff[m, n], 0.00001] // Simplify, "\<   \>", 
        Chop[Hdiff[m, n], 0.00001] // Simplify, "\<   \>", 
        Transpose[
          Chop[bigmatrix[
                  m] . {{Hplus[m, n]}, {Hplus[m + 1, n]}, {nn\[Eta]plus[m, 
                      n]}, {nn\[Eta]plus[m + 1, n]}, {nn\[Rho]plus[m, 
                      n]}, {nn\[Rho]plus[m + 1, n]}, {H\[Kappa]}, {1}} // 
              Simplify, 0.00001]], "\<   \>", 
        Chop[Hplus[m, n]/2, 0.00001] // Simplify, "\<   \>", 
        Chop[\(Hplus[m, n]/
                Sqrt[nn\[Eta]plus[m, n]^2 + nn\[Rho]plus[m, n]^2]\)/2, 
            0.00001] // Simplify, "\<   \>", 
        Chop[H\[Kappa], 0.00001] // Simplify], {m, 2, maxm - 1}]; \)], "Input"],

Cell["\<\
Plotter 1) We draw the full surface here (Poincare ball model for H^3, \
stereographic projection model for S^3, and the usual vector space for R^3): \
\
\>", "Text"],

Cell[BoxData[
    \(Show[
      Table[Graphics3D[
          Polygon[{{\(values\[LeftDoubleBracket]
                      j\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Cos[\(k\ \[Pi]\)\/15], \(values\[LeftDoubleBracket]
                      j\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Sin[\(k\ \[Pi]\)\/15], \(values\[LeftDoubleBracket]
                    j\[RightDoubleBracket]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]}, {\(values\[LeftDoubleBracket]
                      j\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Cos[
                    1\/15\ \((k + 1)\)\ \[Pi]], \(values\[LeftDoubleBracket]
                      j\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Sin[
                    1\/15\ \((k + 1)\)\ \[Pi]], \(values\[LeftDoubleBracket]
                    j\[RightDoubleBracket]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]}, {\(values\[LeftDoubleBracket]
                      j + 1\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Cos[
                    1\/15\ \((k + 1)\)\ \[Pi]], \(values\[LeftDoubleBracket]
                      j + 1\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Sin[
                    1\/15\ \((k + 1)\)\ \[Pi]], \(values\[LeftDoubleBracket]
                    j + 1\[RightDoubleBracket]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]}, {\(values\[LeftDoubleBracket]
                      j + 1\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Cos[\(k\ \[Pi]\)\/15], \(values\[LeftDoubleBracket]
                      j + 1\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Sin[\(k\ \[Pi]\)\/15], \(values\[LeftDoubleBracket]
                    j + 1\[RightDoubleBracket]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]}}]], {j, 1, maxm - 3}, {k, 0, 14}], 
      PlotRange \[Rule] All, AspectRatio \[Rule] Automatic, 
      Boxed \[Rule] False, 
      ViewPoint \[Rule] {4.0, \(-5.0\), 2.0}]; \)], "Input"],

Cell["\<\
Plotter 2) The following is only for moving the picture of the profile curve \
by an isometry of S^3, so should only be used in the S^3 case (it makes the \
picture easier to \"see\"):  \
\>", "Text"],

Cell[BoxData[{
    \(tmpAMoebiusTransformedS3 = 
      ListPlot[MoebiusTransformedValuesS3, 
        PlotStyle \[Rule] PointSize[0.005]]; \), "\n", 
    \(tmpBMoebiusTransformedS3 = 
      ListPlot[MoebiusTransformedValuesS3, 
        PlotStyle \[Rule] PointSize[0.005], 
        PlotJoined \[Rule] True]; \), "\n", 
    \(Show[tmpAMoebiusTransformedS3, tmpBMoebiusTransformedS3, 
      PlotRange \[Rule] All, AspectRatio \[Rule] True]; \)}], "Input"],

Cell["\<\
Plotter 3) The following is only for moving the picture of the profile curve \
into the upper and lower half space models for the two copies of H^3, so \
should only be used in the H^3 case: \
\>", "Text"],

Cell[BoxData[{
    \(tmpAMoebiusTransformed = 
      ListPlot[MoebiusTransformedValues, 
        PlotStyle \[Rule] PointSize[0.005]]; \), "\n", 
    \(tmpBMoebiusTransformed = 
      ListPlot[MoebiusTransformedValues, PlotStyle \[Rule] PointSize[0.005], 
        PlotJoined \[Rule] True]; \), "\n", 
    \(Show[tmpAMoebiusTransformed, tmpBMoebiusTransformed, 
      PlotRange \[Rule] All, AspectRatio \[Rule] True]; \)}], "Input"],

Cell["\<\
Plotter 4) In the case of H^3, we draw the full surface here, using the upper \
and lower half space models: \
\>", "Text"],

Cell[BoxData[{
    \(firstpart = 
      Show[Table[
          Graphics3D[
            Polygon[{{\(MoebiusTransformedValues\[LeftDoubleBracket]
                        j\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Cos[\(k\ \[Pi]\)\/15], \(MoebiusTransformedValues\
\[LeftDoubleBracket]
                        j\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Sin[\(k\ \[Pi]\)\/15], \(MoebiusTransformedValues\
\[LeftDoubleBracket]
                      j\[RightDoubleBracket]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]}, {\(MoebiusTransformedValues\[LeftDoubleBracket]
                        j\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Cos[
                      1\/15\ \((k + 
                            1)\)\ \[Pi]], \(MoebiusTransformedValues\
\[LeftDoubleBracket]
                        j\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Sin[
                      1\/15\ \((k + 
                            1)\)\ \[Pi]], \(MoebiusTransformedValues\
\[LeftDoubleBracket]
                      j\[RightDoubleBracket]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]}, {\(MoebiusTransformedValues\[LeftDoubleBracket]
                        j + 1\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Cos[
                      1\/15\ \((k + 
                            1)\)\ \[Pi]], \(MoebiusTransformedValues\
\[LeftDoubleBracket]j + 
                          1\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Sin[
                      1\/15\ \((k + 
                            1)\)\ \[Pi]], \(MoebiusTransformedValues\
\[LeftDoubleBracket]j + 
                        1\[RightDoubleBracket]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]}, {\(MoebiusTransformedValues\[LeftDoubleBracket]
                        j + 1\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Cos[\(k\ \[Pi]\)\/15], \(MoebiusTransformedValues\
\[LeftDoubleBracket]j + 
                          1\[RightDoubleBracket]\)\[LeftDoubleBracket]1\
\[RightDoubleBracket]\ Sin[\(k\ \[Pi]\)\/15], \(MoebiusTransformedValues\
\[LeftDoubleBracket]j + 
                        1\[RightDoubleBracket]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]}}]], {j, 1, maxm - 3}, {k, 0, 14}], 
        PlotRange \[Rule] All, AspectRatio \[Rule] Automatic, 
        Boxed \[Rule] False, 
        ViewPoint \[Rule] {4.0, \(-5.0\), 2.0}]\), "\n", 
    \(b = 0.000001; \), "\n", 
    \(a = 0.05; \), "\n", 
    \(rad = 1.0; \), "\[IndentingNewLine]", 
    \(secondpart = 
      Show[Graphics3D[
          Polygon[{{rad\ Cos[0\ \[Pi]/28], rad\ Sin[0\ \[Pi]/28], 
                b}, {rad\ Cos[1\ \[Pi]/28], rad\ Sin[1\ \[Pi]/28], 
                b}, {rad\ Cos[2\ \[Pi]/28], rad\ Sin[2\ \[Pi]/28], 
                b}, {rad\ Cos[3\ \[Pi]/28], rad\ Sin[3\ \[Pi]/28], 
                b}, {rad\ Cos[4\ \[Pi]/28], rad\ Sin[4\ \[Pi]/28], 
                b}, {rad\ Cos[5\ \[Pi]/28], rad\ Sin[5\ \[Pi]/28], 
                b}, {rad\ Cos[6\ \[Pi]/28], rad\ Sin[6\ \[Pi]/28], 
                b}, {rad\ Cos[7\ \[Pi]/28], rad\ Sin[7\ \[Pi]/28], 
                b}, {rad\ Cos[8\ \[Pi]/28], rad\ Sin[8\ \[Pi]/28], 
                b}, {rad\ Cos[9\ \[Pi]/28], rad\ Sin[9\ \[Pi]/28], 
                b}, {rad\ Cos[10\ \[Pi]/28], rad\ Sin[10\ \[Pi]/28], 
                b}, {rad\ Cos[11\ \[Pi]/28], rad\ Sin[11\ \[Pi]/28], 
                b}, {rad\ Cos[12\ \[Pi]/28], rad\ Sin[12\ \[Pi]/28], 
                b}, {rad\ Cos[13\ \[Pi]/28], rad\ Sin[13\ \[Pi]/28], 
                b}, {rad\ Cos[14\ \[Pi]/28], rad\ Sin[14\ \[Pi]/28], 
                b}, {rad\ Cos[15\ \[Pi]/28], rad\ Sin[15\ \[Pi]/28], 
                b}, {rad\ Cos[16\ \[Pi]/28], rad\ Sin[16\ \[Pi]/28], 
                b}, {rad\ Cos[17\ \[Pi]/28], rad\ Sin[17\ \[Pi]/28], 
                b}, {rad\ Cos[18\ \[Pi]/28], rad\ Sin[18\ \[Pi]/28], 
                b}, {rad\ Cos[19\ \[Pi]/28], rad\ Sin[19\ \[Pi]/28], 
                b}, {rad\ Cos[20\ \[Pi]/28], rad\ Sin[20\ \[Pi]/28], 
                b}, {rad\ Cos[21\ \[Pi]/28], rad\ Sin[21\ \[Pi]/28], 
                b}, {rad\ Cos[22\ \[Pi]/28], rad\ Sin[22\ \[Pi]/28], 
                b}, {rad\ Cos[23\ \[Pi]/28], rad\ Sin[23\ \[Pi]/28], 
                b}, {rad\ Cos[24\ \[Pi]/28], rad\ Sin[24\ \[Pi]/28], 
                b}, {rad\ Cos[25\ \[Pi]/28], rad\ Sin[25\ \[Pi]/28], 
                b}, {rad\ Cos[26\ \[Pi]/28], rad\ Sin[26\ \[Pi]/28], 
                b}, {rad\ Cos[27\ \[Pi]/28], rad\ Sin[27\ \[Pi]/28], 
                b}, {rad\ Cos[28\ \[Pi]/28], rad\ Sin[28\ \[Pi]/28], b}}]], 
        PlotRange \[Rule] All, AspectRatio \[Rule] Automatic, 
        Boxed \[Rule] False, 
        ViewPoint \[Rule] {4.0, \(-5.0\), 
            2.0}]; \[IndentingNewLine]\), "\[IndentingNewLine]", 
    \(figure = 
      Show[firstpart, secondpart, 
        ViewPoint \[Rule] {6.0, \(-7.0\), 1.5}]\)}], "Input"]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 685}},
WindowSize->{1016, 651},
WindowMargins->{{0, Automatic}, {Automatic, 0}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 2323, 35, 318, "Text"],
Cell[4080, 88, 237, 5, 52, "Text"],
Cell[4320, 95, 938, 19, 244, "Input"],
Cell[5261, 116, 196, 4, 52, "Text"],
Cell[5460, 122, 1164, 25, 398, "Input"],
Cell[6627, 149, 222, 5, 52, "Text"],
Cell[6852, 156, 948, 21, 380, "Input"],
Cell[7803, 179, 183, 4, 52, "Text"],
Cell[7989, 185, 1347, 32, 550, "Input"],
Cell[9339, 219, 213, 4, 52, "Text"],
Cell[9555, 225, 1185, 24, 410, "Input"],
Cell[10743, 251, 409, 7, 71, "Text"],
Cell[11155, 260, 1459, 30, 390, "Input"],
Cell[12617, 292, 259, 5, 52, "Text"],
Cell[12879, 299, 1195, 22, 290, "Input"],
Cell[14077, 323, 209, 4, 52, "Text"],
Cell[14289, 329, 1109, 20, 290, "Input"],
Cell[15401, 351, 258, 5, 52, "Text"],
Cell[15662, 358, 1162, 23, 491, "Input"],
Cell[16827, 383, 237, 5, 52, "Text"],
Cell[17067, 390, 902, 18, 259, "Input"],
Cell[17972, 410, 203, 4, 52, "Text"],
Cell[18178, 416, 1165, 21, 290, "Input"],
Cell[19346, 439, 206, 4, 52, "Text"],
Cell[19555, 445, 1187, 20, 330, "Input"],
Cell[20745, 467, 232, 5, 52, "Text"],
Cell[20980, 474, 312, 8, 170, "Input"],
Cell[21295, 484, 249, 5, 52, "Text"],
Cell[21547, 491, 356, 8, 170, "Input"],
Cell[21906, 501, 179, 4, 52, "Text"],
Cell[22088, 507, 352, 8, 170, "Input"],
Cell[22443, 517, 182, 4, 52, "Text"],
Cell[22628, 523, 355, 8, 170, "Input"],
Cell[22986, 533, 179, 4, 52, "Text"],
Cell[23168, 539, 360, 8, 170, "Input"],
Cell[23531, 549, 543, 9, 90, "Text"],
Cell[24077, 560, 355, 8, 170, "Input"],
Cell[24435, 570, 547, 9, 90, "Text"],
Cell[24985, 581, 364, 8, 170, "Input"],
Cell[25352, 591, 216, 4, 52, "Text"],
Cell[25571, 597, 330, 8, 170, "Input"],
Cell[25904, 607, 216, 4, 52, "Text"],
Cell[26123, 613, 432, 8, 170, "Input"],
Cell[26558, 623, 216, 4, 52, "Text"],
Cell[26777, 629, 432, 8, 170, "Input"],
Cell[27212, 639, 216, 4, 52, "Text"],
Cell[27431, 645, 432, 8, 170, "Input"],
Cell[27866, 655, 302, 5, 52, "Text"],
Cell[28171, 662, 378, 8, 170, "Input"],
Cell[28552, 672, 278, 5, 52, "Text"],
Cell[28833, 679, 359, 8, 170, "Input"],
Cell[29195, 689, 573, 9, 90, "Text"],
Cell[29771, 700, 359, 8, 170, "Input"],
Cell[30133, 710, 550, 9, 90, "Text"],
Cell[30686, 721, 359, 8, 170, "Input"],
Cell[31048, 731, 598, 10, 90, "Text"],
Cell[31649, 743, 360, 8, 170, "Input"],
Cell[32012, 753, 524, 10, 90, "Text"],
Cell[32539, 765, 1504, 26, 211, "Input"],
Cell[34046, 793, 126, 3, 33, "Text"],
Cell[34175, 798, 2078, 41, 311, "Input"],
Cell[36256, 841, 232, 4, 52, "Text"],
Cell[36491, 847, 3076, 64, 558, "Input"],
Cell[39570, 913, 263, 5, 52, "Text"],
Cell[39836, 920, 948, 17, 150, "Input"],
Cell[40787, 939, 263, 5, 52, "Text"],
Cell[41053, 946, 816, 14, 150, "Input"],
Cell[41872, 962, 176, 4, 33, "Text"],
Cell[42051, 968, 2033, 34, 209, "Input"],
Cell[44087, 1004, 210, 4, 33, "Text"],
Cell[44300, 1010, 451, 9, 70, "Input"],
Cell[44754, 1021, 215, 4, 33, "Text"],
Cell[44972, 1027, 430, 8, 70, "Input"],
Cell[45405, 1037, 133, 3, 33, "Text"],
Cell[45541, 1042, 4925, 88, 665, "Input"]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

